==> everycomp-1.20-2.8.1-forge-sources.jar: net/mehvahdjukaar/every_compat/common_classes/CompatChestBlockEntity.java <==
package net.mehvahdjukaar.every_compat.common_classes;

import net.mehvahdjukaar.moonlight.api.platform.ClientHelper;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.minecraft.core.BlockPos;
import net.minecraft.network.chat.Component;
import net.minecraft.world.level.Level;
import net.minecraft.world.level.block.Block;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.entity.ChestBlockEntity;
import net.minecraft.world.level.block.state.BlockState;

public class CompatChestBlockEntity extends ChestBlockEntity {
    private final WoodType woodType;
    private final boolean trapped;

    public CompatChestBlockEntity(BlockEntityType<?> arg, BlockPos pos, BlockState state) {
        super(arg, pos, state);
        var w = WoodTypeRegistry.INSTANCE.getBlockTypeOf(state.m_60734_());
        this.woodType = w == null ? WoodTypeRegistry.OAK_TYPE : w;
        this.trapped = state.m_60734_() instanceof CompatTrappedChestBlock;
    }

    public WoodType getWoodType() {
        return woodType;
    }

    @Override
    protected void m_142151_(Level level, BlockPos pos, BlockState state, int eventId, int eventParam) {
        super.m_142151_(level, pos, state, eventId, eventParam);
        if (trapped && eventId != eventParam) {
            Block block = state.m_60734_();
            level.m_46672_(pos, block);
            level.m_46672_(pos.m_7495_(), block);
        }
    }

    public boolean isTrapped() {
        return trapped;
    }

    @Override
    protected Component m_6820_() {
        return Component.m_237110_("container.everycomp.chest.name", Component.m_237115_(woodType.getTranslationKey()).getString());
    }
}

==> everycomp-1.20-2.9.12-forge-sources.jar: net/mehvahdjukaar/every_compat/common_classes/CompatChestBlockEntity.java <==
package net.mehvahdjukaar.every_compat.common_classes;

import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.minecraft.core.BlockPos;
import net.minecraft.network.chat.Component;
import net.minecraft.world.level.Level;
import net.minecraft.world.level.block.Block;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.entity.ChestBlockEntity;
import net.minecraft.world.level.block.state.BlockState;

public class CompatChestBlockEntity extends ChestBlockEntity {
    private final WoodType woodType;
    private final boolean trapped;

    public CompatChestBlockEntity(BlockEntityType<?> blockEntityType, BlockPos pos, BlockState state) {
        super(blockEntityType, pos, state);
        var w = WoodTypeRegistry.INSTANCE.getBlockTypeOf(state.m_60734_());
        this.woodType = w == null ? VanillaWoodTypes.OAK : w;
        this.trapped = state.m_60734_() instanceof CompatTrappedChestBlock;
    }

    public WoodType getWoodType() {
        return woodType;
    }

    @Override
    protected void m_142151_(Level level, BlockPos pos, BlockState state, int eventId, int eventParam) {
        super.m_142151_(level, pos, state, eventId, eventParam);
        if (trapped && eventId != eventParam) {
            Block block = state.m_60734_();
            level.m_46672_(pos, block);
            level.m_46672_(pos.m_7495_(), block);
        }
    }

    public boolean isTrapped() {
        return trapped;
    }

    @Override
    protected Component m_6820_() {
        return Component.m_237110_("container.everycomp.chest.name", Component.m_237115_(woodType.getTranslationKey()).getString());
    }
}
